---
Summary: Read config file
Status: Done
---

# Description

Settings can be stored in `.scrum.toml`, `scrum.toml` or as part of `pyproject.taml`. In all cases, under the `[tool.scrummd]` heading.

Initial settings that must be supported are

| Setting    | Description                                                           |
| ---------- | --------------------------------------------------------------------- |
| strict     | Fail on any issue with the collection rather than trying to persevere |
| scrum_path | Path of the scrum cards/meta                                          |

# Cucumber

**GIVEN** settings stored in one of the config files

**WHEN** any part of scrummd is run

**THEN** the stored settings are used
